# -*- coding: utf-8 -*-
# FreeCAD script to create stairs for Seed Home v2
# https://wiki.opensourceecology.org/wiki/Seed_Home_v2
#
# 2021 - Modified from https://github.com/felipe-m/tutorial_freecad_wb
#
#***************************************************************************
#*   (c) Felipe Machado   2017                                             *
#*   https://github.com/felipe-m/tutorial_freecad_wb                       *
#*                                                                         *
#*   This file is part of the FreeCAD CAx development system.              *
#*                                                                         *
#*   This program is free software; you can redistribute it and/or modify  *
#*   it under the terms of the GNU Lesser General Public License (LGPL)    *
#*   as published by the Free Software Foundation; either version 2 of     *
#*   the License, or (at your option) any later version.                   *
#*   for detail see the LICENCE text file.                                 *
#*                                                                         *
#*   FreeCAD is distributed in the hope that it will be useful,            *
#*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
#*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
#*   GNU Lesser General Public License for more details.                   *
#*                                                                         *
#*   You should have received a copy of the GNU Library General Public     *
#*   License along with FreeCAD; if not, write to the Free Software        *
#*   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
#*   USA                                                                   *
#*                                                                         *
#***************************************************************************/


import PySide
from PySide import QtCore, QtGui
import FreeCAD
import FreeCADGui
import Part
import os

__dir__ = os.path.dirname(__file__)

def MakeBox(box_len, box_wid, box_hei, box_x, box_y, box_z, box_name, box_t=0):
    doc = FreeCAD.ActiveDocument
    box =  doc.addObject("Part::Box",box_name)
    box.Length = FreeCAD.Units.parseQuantity(str(box_len) + 'in')
    box.Width  = FreeCAD.Units.parseQuantity(str(box_wid) + 'in')
    box.Height = FreeCAD.Units.parseQuantity(str(box_hei) + 'in')
    box.ViewObject.Transparency=box_t
    X = FreeCAD.Units.parseQuantity(str(box_x) + 'in')
    Y  = FreeCAD.Units.parseQuantity(str(box_y) + 'in')
    Z = FreeCAD.Units.parseQuantity(str(box_z) + 'in')
    box.Placement = FreeCAD.Placement(FreeCAD.Vector(X,Y,Z),FreeCAD.Rotation(FreeCAD.Vector(0,0,1),0))

def MakeStep(step, stepSize):
    stepno = str(step)
    x = 10.5 * step
    z = stepSize * step
    MakeBox(11.25, 42.125, 1.5, x, 0, z-1.5, "Step_" + stepno)
    MakeBox(0.375, 42.125, stepSize, x+0.75, 0, z-1.5-stepSize, "Step_" + stepno + '_Riser')
    MakeBox(11.25, 42.125, 1.5, x+1.125, 0, z-3, "Step_" + stepno + '_Base')
    MakeBox(32, 1.5, 3.5, x+1.125, 0, z-6.5, "Step_" + stepno + '_Support1')
    MakeBox(32, 1.5, 3.5, x+1.125, 40.6252, z-6.5, "Step_" + stepno + '_Support2')


class _MakeStairsCmd:

    def Activated(self):
        stepSize = 7.625
        topStep = 15
        MakeBox(10, 42.125, 0.05, 0, 0, -0.05, "Zero", 70)
        for step in range(1, topStep):
            MakeStep(step, stepSize)
        MakeBox(10, 42.125, 0.05, topStep*10.5, 0, topStep*stepSize-0.05, "Top", 70)
        FreeCADGui.activeDocument().activeView().viewAxonometric()
        FreeCADGui.SendMsgToActiveView("ViewFit")


    def GetResources(self):
        # icon and command information
        return {
            'Pixmap': __dir__ + '/icons/makebox_cmd.svg',
            'MenuText': 'Stairs',
            'ToolTip': 'Create Stairs'}

    def IsActive(self):
        # The command will be active if there is an active document
        return not FreeCAD.ActiveDocument is None


FreeCADGui.addCommand('Make_Stairs', _MakeStairsCmd())
